# Generated by Django 3.1.14 on 2022-05-13 10:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('idp_user', '0002_auto_20220120_1617'),
    ]

    operations = [
        migrations.RenameField(
            model_name='userrole',
            old_name='app_config',
            new_name='app_entities_restrictions',
        ),
    ]
